@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: dlsof.h,v 1.40 2008/04/15 13:31:47 abe Exp $
+ * $Id: dlsof.h,v 1.42 2009/03/25 19:23:06 abe Exp $
  */
 
 
@@ -67,6 +67,12 @@
 #define	_KERNEL	1
 #  endif	/* FREEBSDV>=5000 */
 #include <sys/conf.h>
+
+#  if	defined(HAS_CONF_MINOR)
+#undef	minor
+#include "fbsd_minor.h"
+#  endif	/* defined(HAS_CONF_MINOR) */
+
 #  if	FREEBSDV>=5000
 #undef	_KERNEL
 #  endif	/* FREEBSDV>=5000 */
@@ -282,7 +288,35 @@ struct vop_generic_args;
 #define	_KERNEL
 #define	KERNEL
 #include <sys/fcntl.h>
+
+/*
+ * The following circumventions were first needed in FreeBSD 8.0-CURRENT some
+ * time in August 2008 to avoid conflicts in /usr/src/sys/sys/libkern.h> and
+ * /usr/src/sys/sys/systm.h, called by <sys/file.h> or the header files it
+ * #include's when KERNEL or _KERNEL is #define'd.
+ *
+ * The circumventions may be needed or may be erroneous for earlier FreeBSD
+ * versions where testing was not possible.
+ */
+
+#define	intrmask_t	int
+#define	log	log_kernel_lsof
+#define	pause	pause_kernel_lsof
+#define	setenv	setenv_kernel_lsof
+#define	uintfptr_t	int
+#define	_SYS_LIBKERN_H_
 #include <sys/file.h>
+
+/*
+ * Attempt to remove the circumventions.
+ */
+
+#undef	_SYS_LIBKERN_H_
+#undef	intrmask_t_lsof
+#undef	log_kernel_lsof
+#undef	pause_kernel_lsof
+#undef	setenv_kernel_lsof
+#undef	uintfptr_t
 #undef	_KERNEL
 #undef	KERNEL
 
@@ -311,9 +345,9 @@ struct vop_advlock_args { int dummy; };	/* to pacify lf_advlock() prototype */
 #include <sys/sx.h>
 #   endif	/* defined(HAS_SYS_SX_H) */
 
-#   if	defined(HAS_SI_PRIV)
+#   if	defined(HAS_SI_PRIV) || defined(HAS_CONF_MINOR) || defined(HAS_CDEV2PRIV)
 #include <fs/devfs/devfs_int.h>
-#   endif	/* defined(SI_PRIV) */
+#   endif	/* defined(SI_PRIV) || defined(HAS_CONF_MINOR) || defined(HAS_CDEV2PRIV) */
 
 #include <fs/devfs/devfs.h>
 #undef	_KERNEL
