@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: dlsof.h,v 1.44 2007/04/24 16:23:15 abe Exp $
+ * $Id: dlsof.h,v 1.45 2009/03/25 19:22:16 abe Exp $
  */
 
 
@@ -317,6 +317,11 @@ extern int nlist();
 #define	DINAMEL		32
 #define	DIRTYPE		dirent
 
+# if	solaris>=100000
+#define	GET_MAJ_DEV(d)	((major_t)(d >> L_BITSMINOR & L_MAXMAJ))
+#define	GET_MIN_DEV(d)	((minor_t)(d & L_MAXMIN))
+# endif	/* solaris >= 100000 */
+
 # if	solaris>=70000
 typedef	uintptr_t	KA_T;
 # else	/* solaris<70000 */
