@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dsock.c,v 1.27 2007/04/24 16:23:15 abe Exp $";
+static char *rcsid = "$Id: dsock.c,v 1.28 2008/10/21 16:16:42 abe Exp $";
 #endif
 
 
@@ -91,6 +91,52 @@ static char *rcsid = "$Id: dsock.c,v 1.27 2007/04/24 16:23:15 abe Exp $";
 #endif	/* defined(HASSOOPT) */
 
 
+/*
+ * build_IPstates() -- build the TCP and UDP state tables
+ */
+
+void
+build_IPstates()
+{
+	if (!TcpSt) {
+	    (void) enter_IPstate("TCP", "CLOSED", TCPS_CLOSED);
+	    (void) enter_IPstate("TCP", "IDLE", TCPS_IDLE);
+	    (void) enter_IPstate("TCP", "BOUND", TCPS_BOUND);
+	    (void) enter_IPstate("TCP", "LISTEN", TCPS_LISTEN);
+	    (void) enter_IPstate("TCP", "SYN_SENT", TCPS_SYN_SENT);
+	    (void) enter_IPstate("TCP", "SYN_RCVD", TCPS_SYN_RCVD);
+	    (void) enter_IPstate("TCP", "ESTABLISHED", TCPS_ESTABLISHED);
+	    (void) enter_IPstate("TCP", "CLOSE_WAIT", TCPS_CLOSE_WAIT);
+	    (void) enter_IPstate("TCP", "FIN_WAIT_1", TCPS_FIN_WAIT_1);
+	    (void) enter_IPstate("TCP", "CLOSING", TCPS_CLOSING);
+	    (void) enter_IPstate("TCP", "LAST_ACK", TCPS_LAST_ACK);
+	    (void) enter_IPstate("TCP", "FIN_WAIT_2", TCPS_FIN_WAIT_2);
+	    (void) enter_IPstate("TCP", "TIME_WAIT", TCPS_TIME_WAIT);
+	    (void) enter_IPstate("TCP", (char *)NULL, 0);
+	}
+	if (!UdpSt) {
+	    (void) enter_IPstate("UDP", "Unbound", TS_UNBND);
+	    (void) enter_IPstate("UDP", "Wait_BIND_REQ_Ack", TS_WACK_BREQ);
+	    (void) enter_IPstate("UDP", "Wait_UNBIND_REQ_Ack", TS_WACK_UREQ);
+	    (void) enter_IPstate("UDP", "Idle", TS_IDLE);
+	    (void) enter_IPstate("UDP", "Wait_OPT_REQ_Ack", TS_WACK_OPTREQ);
+	    (void) enter_IPstate("UDP", "Wait_CONN_REQ_Ack", TS_WACK_CREQ);
+	    (void) enter_IPstate("UDP", "Wait_CONN_REQ_Confirm", TS_WCON_CREQ);
+	    (void) enter_IPstate("UDP", "Wait_CONN_IND_Response", TS_WRES_CIND);
+	    (void) enter_IPstate("UDP", "Wait_CONN_RES_Ack", TS_WACK_CRES);
+	    (void) enter_IPstate("UDP", "Wait_Data_Xfr", TS_DATA_XFER);
+	    (void) enter_IPstate("UDP", "Wait_Read_Release", TS_WIND_ORDREL);
+	    (void) enter_IPstate("UDP", "Wait_Write_Release", TS_WREQ_ORDREL);
+	    (void) enter_IPstate("UDP", "Wait_DISCON_REQ_Ack", TS_WACK_DREQ6);
+	    (void) enter_IPstate("UDP", "Wait_DISCON_REQ_Ack", TS_WACK_DREQ7);
+	    (void) enter_IPstate("UDP", "Wait_DISCON_REQ_Ack", TS_WACK_DREQ9);
+	    (void) enter_IPstate("UDP", "Wait_DISCON_REQ_Ack", TS_WACK_DREQ10);
+	    (void) enter_IPstate("UDP", "Wait_DISCON_REQ_Ack", TS_WACK_DREQ11);
+	    (void) enter_IPstate("UDP", (char *)NULL, 0);
+	}
+}
+
+
 /*
  * print_tcptpi() - print TCP/TPI info
  */
@@ -108,108 +154,34 @@ print_tcptpi(nl)
 	if (Ftcptpi & TCPTPI_STATE) {
 	    switch (Lf->lts.type) {
 	    case 0:				/* TCP */
-		switch ((i = Lf->lts.state.i)) {
-		case TCPS_CLOSED:
-		    cp = "CLOSED";
-		    break;
-		case TCPS_IDLE:
-		    cp = "IDLE";
-		    break;
-		case TCPS_BOUND:
-		    cp = "BOUND";
-		    break;
-		case TCPS_LISTEN:
-		    cp = "LISTEN";
-		    break;
-		case TCPS_SYN_SENT:
-		    cp = "SYN_SENT";
-		    break;
-		case TCPS_SYN_RCVD:
-		    cp = "SYN_RCVD";
-		    break;
-		case TCPS_ESTABLISHED:
-		    cp = "ESTABLISHED";
-		    break;
-		case TCPS_CLOSE_WAIT:
-		    cp = "CLOSE_WAIT";
-		    break;
-		case TCPS_FIN_WAIT_1:
-		    cp = "FIN_WAIT_1";
-		    break;
-		case TCPS_CLOSING:
-		    cp = "CLOSING";
-		    break;
-		case TCPS_LAST_ACK:
-		    cp = "LAST_ACK";
-		    break;
-		case TCPS_FIN_WAIT_2:
-		    cp = "FIN_WAIT_2";
-		    break;
-		case TCPS_TIME_WAIT:
-		    cp = "TIME_WAIT";
-		    break;
-		default:
-		    (void) snpf(sbuf, sizeof(sbuf), "UknownState_%d", i);
+		if (!TcpSt)
+		    (void) build_IPstates();
+		if ((i = Lf->lts.state.i + TcpStOff) < 0 || i >= TcpNstates) {
+		    (void) snpf(sbuf, sizeof(sbuf), "UNKNOWN_TCP_STATE_%d",
+			Lf->lts.state.i);
 		    cp = sbuf;
-		}
+		} else
+		    cp = TcpSt[i];
 		break;
 	    case 1:				/* TPI */
-		switch ((u = Lf->lts.state.ui)) {
-		case TS_UNBND:
-		    cp = "Unbound";
-		    break;
-		case TS_WACK_BREQ:
-		    cp = "Wait_BIND_REQ_Ack";
-		    break;
-		case TS_WACK_UREQ:
-		    cp = "Wait_UNBIND_REQ_Ack";
-		    break;
-		case TS_IDLE:
-		    cp = "Idle";
-		    break;
-		case TS_WACK_OPTREQ:
-		    cp = "Wait_OPT_REQ_Ack";
-		    break;
-		case TS_WACK_CREQ:
-		    cp = "Wait_CONN_REQ_Ack";
-		    break;
-		case TS_WCON_CREQ:
-		    cp = "Wait_CONN_REQ_Confirm";
-		    break;
-		case TS_WRES_CIND:
-		    cp = "Wait_CONN_IND_Response";
-		    break;
-		case TS_WACK_CRES:
-		    cp = "Wait_CONN_RES_Ack";
-		    break;
-		case TS_DATA_XFER:
-		    cp = "Wait_Data_Xfr";
-		    break;
-		case TS_WIND_ORDREL:
-		    cp = "Wait_Read_Release";
-		    break;
-		case TS_WREQ_ORDREL:
-		    cp = "Wait_Write_Release";
-		    break;
-		case TS_WACK_DREQ6:
-		case TS_WACK_DREQ7:
-		case TS_WACK_DREQ9:
-		case TS_WACK_DREQ10:
-		case TS_WACK_DREQ11:
-		    cp = "Wait_DISCON_REQ_Ack";
-		    break;
-		default:
-		    (void) snpf(sbuf, sizeof(sbuf), "UNKNOWN_TPI_STATE_%u", u);
+		if (!UdpSt)
+		    (void) build_IPstates();
+		if ((u = Lf->lts.state.ui + UdpStOff) < 0 || u >= UdpNstates) {
+		    (void) snpf(sbuf, sizeof(sbuf), "UNKNOWN_UDP_STATE_%u",
+			Lf->lts.state.ui);
 		    cp = sbuf;
+		} else
+		    cp = UdpSt[u];
+	    }
+	    if (cp) {
+		if (Ffield)
+		    (void) printf("%cST=%s%c", LSOF_FID_TCPTPI, cp, Terminator);
+		else {
+		    putchar('(');
+		    (void) fputs(cp, stdout);
 		}
+		ps++;
 	    }
-	    if (Ffield)
-		(void) printf("%cST=%s%c", LSOF_FID_TCPTPI, cp, Terminator);
-	    else {
-		putchar('(');
-		(void) fputs(cp, stdout);
-	    }
-	    ps++;
 	}
 
 #if	defined(HASTCPTPIQ)
@@ -632,8 +604,10 @@ process_socket(sa, ty)
 	    ||  ((FnetTy == 6) && (af == AF_INET6))
 # endif	/* defined(HASIPv6) */
 
-	    )
-		Lf->sf |= SELNET;
+	    ) {
+		if (!TcpStIn && !UdpStIn)
+		    Lf->sf |= SELNET;
+	    }
 	}
 	Lf->inp_ty = 2;
 /*
@@ -700,11 +674,90 @@ process_socket(sa, ty)
 		}
 #endif        /* solaris<=90000 || !defined(HAS_IPCLASSIFIER_H) */
 
+		if (tcs && TcpNstates) {
+		    int s = (int)tc.tcp_state + TcpStOff;
+		/*
+		 * Check for TCP state inclusion or exclusion.
+		 */
+
+		    if (s < TcpNstates) {
+			if (TcpStXn) {
+			    if (TcpStX[s]) {
+				Lf->sf &= ~SELNET;
+				Lf->sf |= SELEXCLF;
+				return;
+			    }
+			}
+			if (TcpStIn) {
+			    if (TcpStI[s]) {
+				TcpStI[s] = 2;
+				Lf->sf |= SELNET;
+			    } else {
+				Lf->sf &= ~SELNET;
+				Lf->sf |= SELEXCLF;
+				return;
+			    }
+			}
+		    }
+		}
+		if (!(Lf->sf & SELNET) && !TcpStIn && UdpStIn) {
+		    if (Fnet) {
+			if (!FnetTy
+			||  (FnetTy == 4) && (af == AF_INET)
+
+#if	defined(HASIPv6)
+			||  (FnetTy == 6) && (af == AF_INET6)
+#endif 	/* defined(HASIPv6) */
+
+			) {
+			    Lf->sf |= SELNET;
+			}
+		    }
+		}
 		continue;
 	    }
 	    if (strncasecmp(tbuf, "UDP", 3) == 0) {
 		if (kread((KA_T)q.q_ptr, (char *)&uc, sizeof(uc)) == 0)
 		    ucs = 1;
+		if (ucs && UdpNstates) {
+		    unsigned int s = (unsigned int)uc.udp_state + UdpStOff;
+		/*
+		 * Check for UDP state inclusion or exclusion.
+		 */
+
+		    if (s < UdpNstates) {
+			if (UdpStXn) {
+			    if (UdpStX[s]) {
+				Lf->sf &= ~SELNET;
+				Lf->sf |= SELEXCLF;
+				return;
+			    }
+			}
+			if (UdpStIn) {
+			    if (UdpStI[s]) {
+				UdpStI[s] = 2;
+				Lf->sf |= SELNET;
+			    } else {
+				Lf->sf |= SELEXCLF;
+				return;
+			    }
+			}
+		    }
+		}
+		if (!(Lf->sf & SELNET) && TcpStIn && !UdpStIn) {
+		    if (Fnet) {
+			if (!FnetTy
+			||  (FnetTy == 4) && (af == AF_INET)
+
+#if	defined(HASIPv6)
+			||  (FnetTy == 6) && (af == AF_INET6)
+#endif 	/* defined(HASIPv6) */
+
+			) {
+			    Lf->sf |= SELNET;
+			}
+		    }
+		}
 		continue;
 	    }
 	}
