@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dstore.c,v 1.21 2007/04/24 16:23:15 abe Exp $";
+static char *rcsid = "$Id: dstore.c,v 1.22 2009/03/25 19:22:16 abe Exp $";
 #endif
 
 
@@ -86,6 +86,7 @@ struct drive_Nl Drive_Nl[] = {
 	{ "ctfstmpl",	"ctfs_ops_tmpl",	 },
 	{ "cvops",	"cachefs_vnodeops"	 },
 	{ "clmaj",	"clonemaj"		 },
+	{ "clmaj_alt",	"clone_major"		 },
 	{ "fdops",	"fdvnodeops"		 },
 	{ "fvops",	"fifo_vnodeops"		 },
 	{ "hvops",	"hsfs_vnodeops"		 },
@@ -121,6 +122,7 @@ struct drive_Nl Drive_Nl[] = {
 	{ "sam3vops",	"samfs_vnodeopsp"	 },
 	{ "sam4vops",	"samfs_client_vnodeopsp" },
 	{ "sgvops",	"segvn_ops"		 },
+	{ "shvops",	"sharefs_ops_data"	 },
 	{ "sckvops",	"sock_vnodeops"		 },
 	{ "spvops",	"spec_vnodeops"		 },
 	{ "sncavops",	"socknca_vnodeops"	 },
